@@ -36,7 +36,7 @@ fi
 #
 # SIG(0) required cryptographic support which may not be configured.
 #
-keyname=`$KEYGEN  -q -n HOST -a RSASHA1 -b 1024 -T KEY sig0.example2 2>keyname.err`
+keyname=$($KEYGEN  -q -n HOST -a ${DEFAULT_ALGORITHM} -b 1024 -T KEY sig0.example2 2>keyname.err)
 if test -n "$keyname"
 then
 	cat ns1/example1.db $keyname.key > ns1/example2.db
