@@ -1,5 +1,7 @@
 /*
- * Portions Copyright (C) Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
+ *
+ * SPDX-License-Identifier: MPL-2.0 AND ISC
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -7,8 +9,10 @@
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
- *
- * Portions Copyright (C) Network Associates, Inc.
+ */
+
+/*
+ * Copyright (C) Network Associates, Inc.
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -138,7 +142,7 @@ struct dst_hmac_key {
 	uint8_t key[ISC_MAX_BLOCK_SIZE];
 };
 
-static inline isc_result_t
+static isc_result_t
 getkeybits(dst_key_t *key, struct dst_private_element *element) {
 	uint16_t *bits = (uint16_t *)element->data;
 
@@ -151,7 +155,7 @@ getkeybits(dst_key_t *key, struct dst_private_element *element) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_result_t
+static isc_result_t
 hmac_createctx(const isc_md_type_t *type, const dst_key_t *key,
 	       dst_context_t *dctx) {
 	isc_result_t result;
@@ -168,7 +172,7 @@ hmac_createctx(const isc_md_type_t *type, const dst_key_t *key,
 	return (ISC_R_SUCCESS);
 }
 
-static inline void
+static void
 hmac_destroyctx(dst_context_t *dctx) {
 	isc_hmac_t *ctx = dctx->ctxdata.hmac_ctx;
 	REQUIRE(ctx != NULL);
@@ -177,7 +181,7 @@ hmac_destroyctx(dst_context_t *dctx) {
 	dctx->ctxdata.hmac_ctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 hmac_adddata(const dst_context_t *dctx, const isc_region_t *data) {
 	isc_result_t result;
 	isc_hmac_t *ctx = dctx->ctxdata.hmac_ctx;
@@ -192,12 +196,12 @@ hmac_adddata(const dst_context_t *dctx, const isc_region_t *data) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_result_t
+static isc_result_t
 hmac_sign(const dst_context_t *dctx, isc_buffer_t *sig) {
 	isc_hmac_t *ctx = dctx->ctxdata.hmac_ctx;
 	REQUIRE(ctx != NULL);
-	unsigned int digestlen;
 	unsigned char digest[ISC_MAX_MD_SIZE];
+	unsigned int digestlen = sizeof(digest);
 
 	if (isc_hmac_final(ctx, digest, &digestlen) != ISC_R_SUCCESS) {
 		return (DST_R_OPENSSLFAILURE);
@@ -216,11 +220,11 @@ hmac_sign(const dst_context_t *dctx, isc_buffer_t *sig) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_result_t
+static isc_result_t
 hmac_verify(const dst_context_t *dctx, const isc_region_t *sig) {
 	isc_hmac_t *ctx = dctx->ctxdata.hmac_ctx;
-	unsigned int digestlen;
 	unsigned char digest[ISC_MAX_MD_SIZE];
+	unsigned int digestlen = sizeof(digest);
 
 	REQUIRE(ctx != NULL);
 
@@ -241,7 +245,7 @@ hmac_verify(const dst_context_t *dctx, const isc_region_t *sig) {
 			: DST_R_VERIFYFAILURE);
 }
 
-static inline bool
+static bool
 hmac_compare(const isc_md_type_t *type, const dst_key_t *key1,
 	     const dst_key_t *key2) {
 	dst_hmac_key_t *hkey1, *hkey2;
@@ -259,7 +263,7 @@ hmac_compare(const isc_md_type_t *type, const dst_key_t *key1,
 				  isc_md_type_get_block_size(type)));
 }
 
-static inline isc_result_t
+static isc_result_t
 hmac_generate(const isc_md_type_t *type, dst_key_t *key) {
 	isc_buffer_t b;
 	isc_result_t ret;
@@ -287,13 +291,13 @@ hmac_generate(const isc_md_type_t *type, dst_key_t *key) {
 	return (ret);
 }
 
-static inline bool
+static bool
 hmac_isprivate(const dst_key_t *key) {
 	UNUSED(key);
 	return (true);
 }
 
-static inline void
+static void
 hmac_destroy(dst_key_t *key) {
 	dst_hmac_key_t *hkey = key->keydata.hmac_key;
 	isc_safe_memwipe(hkey, sizeof(*hkey));
@@ -301,7 +305,7 @@ hmac_destroy(dst_key_t *key) {
 	key->keydata.hmac_key = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 hmac_todns(const dst_key_t *key, isc_buffer_t *data) {
 	REQUIRE(key != NULL && key->keydata.hmac_key != NULL);
 	dst_hmac_key_t *hkey = key->keydata.hmac_key;
@@ -316,7 +320,7 @@ hmac_todns(const dst_key_t *key, isc_buffer_t *data) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_result_t
+static isc_result_t
 hmac_fromdns(const isc_md_type_t *type, dst_key_t *key, isc_buffer_t *data) {
 	dst_hmac_key_t *hkey;
 	unsigned int keylen;
@@ -351,7 +355,7 @@ hmac_fromdns(const isc_md_type_t *type, dst_key_t *key, isc_buffer_t *data) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline int
+static int
 hmac__get_tag_key(const isc_md_type_t *type) {
 	if (type == ISC_MD_MD5) {
 		return (TAG_HMACMD5_KEY);
@@ -366,12 +370,11 @@ hmac__get_tag_key(const isc_md_type_t *type) {
 	} else if (type == ISC_MD_SHA512) {
 		return (TAG_HMACSHA512_KEY);
 	} else {
-		INSIST(0);
-		ISC_UNREACHABLE();
+		UNREACHABLE();
 	}
 }
 
-static inline int
+static int
 hmac__get_tag_bits(const isc_md_type_t *type) {
 	if (type == ISC_MD_MD5) {
 		return (TAG_HMACMD5_BITS);
@@ -386,12 +389,11 @@ hmac__get_tag_bits(const isc_md_type_t *type) {
 	} else if (type == ISC_MD_SHA512) {
 		return (TAG_HMACSHA512_BITS);
 	} else {
-		INSIST(0);
-		ISC_UNREACHABLE();
+		UNREACHABLE();
 	}
 }
 
-static inline isc_result_t
+static isc_result_t
 hmac_tofile(const isc_md_type_t *type, const dst_key_t *key,
 	    const char *directory) {
 	dst_hmac_key_t *hkey;
@@ -424,7 +426,7 @@ hmac_tofile(const isc_md_type_t *type, const dst_key_t *key,
 	return (dst__privstruct_writefile(key, &priv, directory));
 }
 
-static inline int
+static int
 hmac__to_dst_alg(const isc_md_type_t *type) {
 	if (type == ISC_MD_MD5) {
 		return (DST_ALG_HMACMD5);
@@ -439,12 +441,11 @@ hmac__to_dst_alg(const isc_md_type_t *type) {
 	} else if (type == ISC_MD_SHA512) {
 		return (DST_ALG_HMACSHA512);
 	} else {
-		INSIST(0);
-		ISC_UNREACHABLE();
+		UNREACHABLE();
 	}
 }
 
-static inline isc_result_t
+static isc_result_t
 hmac_parse(const isc_md_type_t *type, dst_key_t *key, isc_lex_t *lexer,
 	   dst_key_t *pub) {
 	dst_private_t priv;
