@@ -11,7 +11,6 @@
  * information regarding copyright ownership.
  */
 
-#include <inttypes.h>
 #include <sched.h> /* IWYU pragma: keep */
 #include <setjmp.h>
 #include <stdarg.h>
@@ -25,6 +24,7 @@
 #include <cmocka.h>
 
 #include <isc/dir.h>
+#include <isc/print.h>
 #include <isc/string.h>
 #include <isc/util.h>
 
@@ -63,18 +63,16 @@ static void
 rawdata_callback(dns_zone_t *zone, dns_masterrawheader_t *header);
 
 static isc_result_t
-add_callback(void *arg, const dns_name_t *owner, dns_rdataset_t *dataset,
-	     dns_diffop_t op DNS__DB_FLARG) {
+add_callback(void *arg, const dns_name_t *owner, dns_rdataset_t *dataset) {
 	char buf[BIGBUFLEN];
 	isc_buffer_t target;
 	isc_result_t result;
 
 	UNUSED(arg);
-	UNUSED(op);
 
 	isc_buffer_init(&target, buf, BIGBUFLEN);
 	result = dns_rdataset_totext(dataset, owner, false, false, &target);
-	return result;
+	return (result);
 }
 
 static void
@@ -104,11 +102,11 @@ setup_master(void (*warn)(struct dns_rdatacallbacks *, const char *, ...),
 	result = dns_name_fromtext(&dns_origin, &source, dns_rootname, 0,
 				   &target);
 	if (result != ISC_R_SUCCESS) {
-		return result;
+		return (result);
 	}
 
 	dns_rdatacallbacks_init_stdio(&callbacks);
-	callbacks.update = add_callback;
+	callbacks.add = add_callback;
 	callbacks.rawdata = rawdata_callback;
 	callbacks.zone = NULL;
 	if (warn != NULL) {
@@ -118,7 +116,7 @@ setup_master(void (*warn)(struct dns_rdatacallbacks *, const char *, ...),
 		callbacks.error = error;
 	}
 	headerset = false;
-	return result;
+	return (result);
 }
 
 static isc_result_t
@@ -130,11 +128,11 @@ test_master(const char *workdir, const char *testfile,
 
 	result = setup_master(warn, error);
 	if (result != ISC_R_SUCCESS) {
-		return result;
+		return (result);
 	}
 
 	dns_rdatacallbacks_init_stdio(&callbacks);
-	callbacks.update = add_callback;
+	callbacks.add = add_callback;
 	callbacks.rawdata = rawdata_callback;
 	callbacks.zone = NULL;
 	if (warn != NULL) {
@@ -147,7 +145,7 @@ test_master(const char *workdir, const char *testfile,
 	if (workdir != NULL) {
 		result = isc_dir_chdir(workdir);
 		if (result != ISC_R_SUCCESS) {
-			return result;
+			return (result);
 		}
 	}
 
@@ -155,7 +153,7 @@ test_master(const char *workdir, const char *testfile,
 				     dns_rdataclass_in, true, 0, &callbacks,
 				     NULL, NULL, mctx, format, 0);
 
-	return result;
+	return (result);
 }
 
 static void
@@ -398,7 +396,8 @@ ISC_RUN_TEST_IMPL(totext) {
 	rdatalist.covers = dns_rdatatype_none;
 
 	dns_rdataset_init(&rdataset);
-	dns_rdatalist_tordataset(&rdatalist, &rdataset);
+	result = dns_rdatalist_tordataset(&rdatalist, &rdataset);
+	assert_int_equal(result, ISC_R_SUCCESS);
 
 	isc_buffer_init(&target, buf, BIGBUFLEN);
 	result = dns_master_rdatasettotext(dns_rootname, &rdataset,
@@ -473,9 +472,8 @@ ISC_RUN_TEST_IMPL(dumpraw) {
 				   &target);
 	assert_int_equal(result, ISC_R_SUCCESS);
 
-	result = dns_db_create(mctx, ZONEDB_DEFAULT, &dnsorigin,
-			       dns_dbtype_zone, dns_rdataclass_in, 0, NULL,
-			       &db);
+	result = dns_db_create(mctx, "rbt", &dnsorigin, dns_dbtype_zone,
+			       dns_rdataclass_in, 0, NULL, &db);
 	assert_int_equal(result, ISC_R_SUCCESS);
 
 	result = isc_dir_chdir(SRCDIR);
