@@ -13,7 +13,6 @@
 
 /* ! \file */
 
-#include <inttypes.h>
 #include <sched.h> /* IWYU pragma: keep */
 #include <setjmp.h>
 #include <stdarg.h>
@@ -25,6 +24,7 @@
 #include <cmocka.h>
 
 #include <isc/crc64.h>
+#include <isc/print.h>
 #include <isc/result.h>
 #include <isc/util.h>
 
